@@ -81,7 +81,8 @@ void Backend::setupUnity()
 
     KConfigGroup grp(KSharedConfig::openConfig(QStringLiteral("taskmanagerrulesrc")), QStringLiteral("Unity Launcher Mapping"));
 
-    foreach (const QString &key, grp.keyList()) {
+    const QStringList keys = grp.keyList();
+    for (const QString &key : keys) {
         const QString &value = grp.readEntry(key, QString());
         if (value.isEmpty()) {
             continue;
