@@ -4,15 +4,13 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FLAGS_H_
-#define FLAGS_H_
+#pragma once
 
 #include <QMap>
 #include <QObject>
 #include <QString>
 #include <QIcon>
 
-class QIcon;
 class LayoutUnit;
 class KeyboardConfig;
 struct Rules;
@@ -33,5 +31,3 @@ private:
 
     QMap<QString, QIcon> iconMap;
 };
-
-#endif /* FLAGS_H_ */
